@@ -15,6 +15,7 @@ mlVARsample <- function(
   if (!identical(object$input$lags,1)){
     stop("Only supported for lags = 1")
   }
+  
   args <- commandArgs(trailingOnly=TRUE)
   if (length(args)==0){
     args <- 1
@@ -77,13 +78,18 @@ mlVARsample <- function(
   
   # Beta matrices:
   Beta <- object$results$Beta$subject
-  
+
   # Check if all are stationary:
   stationary <- sapply(Beta,function(b){
     ev <- eigen(b[,,1])$values
     all(Re(ev)^2 + Im(ev)^2 < 1)
   })
   
+  
+  if(length(which(!stationary)) >= 1){
+    warning(paste("Non-stationary Beta matrix detected for subject(s): "), paste(which(!stationary), collapse = ", "))
+  }
+  
   # Inverse thetas:
   invTheta <- lapply(object$results$Theta$cov$subject,solve)
   
